Lua_ArenaRewardPanel = class("Lua_ArenaRewardPanel", Lua_DisplayObject);
function Lua_ArenaRewardPanel:ctor(p)
	self:superCall("ctor", p, "ArenaRewardPanel_skin");
end

function Lua_ArenaRewardPanel:buildShowItem()
	self:superCall("buildShowItem");

	self:addLuaEvent("UPDATE_SHOWTIME", self, self.updateShowTime);

	self.rankBg_1:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 871.5 + self.adaptHeight);
	self.rankBg_2:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 654 + self.adaptHeight);

	self.itemIcons = Lua_ItemIconList.new(self.content);
	self.itemIcons:setLocation(-140, 256, 0);
	self.itemIcons:setRectAnchor(7);
	self.itemIcons.pivot = 1;
	self.itemIcons.canClick = true;

	self.itemList = Lua_DragList.new(self.content, 688, 642.5 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_ArenaRewardItem, 688, 139, 1);
	self.itemList:setLocation(0, -11.5, 0);
	self.itemList:setCellSpacing(0, 10);

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 258, 0);
	self.rankNum:setRectAnchor(7);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -5;
	self.rankNum.numAtlas = "number";
	self.rankNum.lastStr = nil;
	self.rankNum.preStr = "ui_djc2_title_0";
	self.rankNum.num = 0;

	self.btnInfo = Array();
	self.btnInfo:add({ textStr = LanUtil.getValue(303014) });
	self.btnInfo:add({ textStr = LanUtil.getValue(303015) });

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setLocation(-174, 139, 0);
	self.btnList:setButtonStyle("arena_atlas_1", "ui_djc_button_008_n", "ui_djc_button_008_p", 170, 62);
	self.btnList:setButtonText(0, 0, "BBABA2", "A5703E", 28, 28, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal);
	self.btnList:setButtonItem(184, 62);
	self.btnList:setClickCallBack(self, self.onBtnClick);
	self.btnList:setData(self.btnInfo);
	self.btnList:setRectAnchor(7);
	self.btnList:setSelected(1);

	self.btnHelp:addClickFuntion(self, self.onBtnHelpClick);
end

function Lua_ArenaRewardPanel:dispose()
	if self.itemIcons ~= nil then
		self.itemIcons:dispose();
		self.itemIcons = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	self:endTimer();
	self:superCall("dispose");
end

function Lua_ArenaRewardPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.rankBg_1:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 871.5 + adaptHeight);
	self.rankBg_2:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 654 + adaptHeight);
	self.itemList:setContentRect(688, 642.5 + adaptHeight);
end

function Lua_ArenaRewardPanel:onBtnClick(index)
	if self.index ~= nil and self.index ~= index then
		self:endTimer();
	end
	self.index = index;
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sReadRewardInfo();

	local arr = DataCenter.arenaUtil:getRewardsArr(index);
	self.itemList:setArrayData(arr);
	self.itemList:moveToIndex(1, true);

	local len = arr:getSize();
	local self_rank = DataCenter.arenaData.self_rank;
	self.rankNum:setEnable(true);
	self.myRank:setEnable(false);
	if self_rank <= 0 then
		self.rankNum:setEnable(false);
		self.myRank:setEnable(true);
		self.itemIcons:setArrayData(arr[len].reward);
	else
		self.rankNum.num = self_rank;
		for i = 1, len do
			if self_rank >= arr[i].rank[1] and self_rank <= arr[i].rank[2] then
				self.itemIcons:setArrayData(arr[i].reward);
				break;
			end
		end
	end
end

function Lua_ArenaRewardPanel:updateShowTime()
	self:startTimer();
	self:updateLeftTime();
end

function Lua_ArenaRewardPanel:startTimer()
	if self.countDown ~= true then
		self.countDown = true;
		Lua_CommonUtil.addTimer("updateLeftTime", 1, self, self.updateLeftTime);
	end
end

function Lua_ArenaRewardPanel:endTimer()
	if self.countDown == true then
		self.countDown = false;
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	end
end

function Lua_ArenaRewardPanel:updateLeftTime()
	local remainTime;
	if self.index == Lua_ArenaData.dailyArenaReward then
		remainTime = DataCenter.arenaData.daily_settle_tick - DataCenter.roleData.serverTime;
	else
		remainTime = DataCenter.arenaData.settle_tick - DataCenter.roleData.serverTime;
	end

	if remainTime <= 0 then
		self:endTimer();
		remainTime = 0;
	end
	self.txtTime.text = Lua_TimeTransform.transSeconds1(remainTime, true, true, true);
end

function Lua_ArenaRewardPanel:onBtnHelpClick(go)
	local tipsData = { des = LanUtil.getValue(303016), posX = 175, posY = -230 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end




















Lua_ArenaRewardItem = class("Lua_ArenaRewardItem", Lua_ListCell);
function Lua_ArenaRewardItem:ctor(p)
	self:superCall("ctor", p, "ArenaRewardItem_skin");
end

function Lua_ArenaRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcons = Lua_ItemIconList.new(self.content);
	self.itemIcons:setLocation(-140, 0, 0);
	self.itemIcons.pivot = 1;

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 0, 0);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -4;
	self.rankNum.numAtlas = "number";
	self.rankNum.preStr = "ui_djc_title_0";
end

function Lua_ArenaRewardItem:dispose()
	if self.itemIcons ~= nil then
		self.itemIcons:dispose();
		self.itemIcons = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self:superCall("dispose");
end

function Lua_ArenaRewardItem:setData(data)
	if data == nil then
		return;
	end

	if data.rank[2] == 9999 then
		self.sprRankBg:setAltas("common_altas_3", "ui_djc_window_004");
		self.rankNum.num = data.rank[1].."+";
	elseif data.rank[1] == data.rank[2] then
		self.sprRankBg:setAltas("common_altas_3", "ui_djc_window_00"..data.rank[1]);
		self.rankNum.num = nil;
	else
		self.sprRankBg:setAltas("common_altas_3", "ui_djc_window_004");
		self.rankNum.num = data.rank[1].."-"..data.rank[2];
	end

	local showWidth = self.sprRankBg.width - 5;
	if self.rankNum.totalWidth >= showWidth then
		local ratioValue = showWidth / self.rankNum.totalWidth;
		self.rankNum:setScale(ratioValue, ratioValue);
	else
		self.rankNum:setScale(1, 1);
	end

	self.itemIcons:setArrayData(data.reward);
end

function Lua_ArenaRewardItem:onPressClick()
	self.itemIcons:onBoundClick();
end